@@ -1,14 +1,35 @@
 use strict;
 use warnings;
 
-package Games::Goban::Board;
-{
-  $Games::Goban::Board::VERSION = '1.102';
-}
+package Games::Goban::Board 1.103;
 use parent qw(Games::Board::Grid);
 # ABSTRACT: a go board built from Games::Board
 
+#pod =head1 SYNOPSIS
+#pod
+#pod   use Games::Goban::Board;
+#pod
+#pod   my $board = Games::Goban::Board->new(size => 19);
+#pod
+#pod   # etc
+#pod
+#pod This class exists is primarily for use (for now) by Games::Goban, which
+#pod currently implements its own board, badly.
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This module provides a class for representing a go board and pieces.
+#pod
+#pod =cut
 
+#pod =head1 METHODS
+#pod
+#pod The methods of this class are not substantially changed from those of
+#pod Games::Board.  Space id's are more go-like.  New pieces are blessed into the
+#pod class Games::Goban::Piece, which provides a few historical methods for
+#pod Games::Goban's consumption.
+#pod
+#pod =cut
 
 my $origin = ord('a');
 
@@ -44,10 +65,7 @@ sub id2index {
   \@loc;
 }
 
-package Games::Goban::Piece;
-{
-  $Games::Goban::Piece::VERSION = '1.102';
-}
+package Games::Goban::Piece 1.103;
 use base qw(Games::Board::Piece);
 
 my $next_id = 0;
@@ -80,13 +98,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Games::Goban::Board - a go board built from Games::Board
 
 =head1 VERSION
 
-version 1.102
+version 1.103
 
 =head1 SYNOPSIS
 
@@ -103,6 +123,18 @@ currently implements its own board, badly.
 
 This module provides a class for representing a go board and pieces.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 The methods of this class are not substantially changed from those of
@@ -120,7 +152,7 @@ Simon Cozens
 
 =item *
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =back
 
